reg.explain <-
function(my.formula, explain=TRUE, ...)

  Regression(my.formula, explain=TRUE, ...)
